stopOverlayService method
Stop the overlay service
This will stop tracking text input and remove any visible overlay bubbles.
Implementation
Future<void> stopOverlayService() async {
return await TypeMatePlatform.instance.stopOverlayService();
}
Stop the overlay service
This will stop tracking text input and remove any visible overlay bubbles.
Future<void> stopOverlayService() async {
return await TypeMatePlatform.instance.stopOverlayService();
}