textFieldFocusedStream property

Stream<void> get textFieldFocusedStream

Stream of text field focused events.

Emits an event whenever a text field gains focus in any application on the device. This requires the accessibility service to be enabled.

The stream is a broadcast stream, allowing multiple listeners.

Example:

TypeMate.instance.textFieldFocusedStream.listen((_) {
  print('User started typing in a text field!');
  // Show additional UI, start spell checking, etc.
});

Note: This only works when the accessibility service is enabled and the overlay service is running.

Implementation

Stream<void> get textFieldFocusedStream => _textFieldFocusedController.stream;