textFieldUnfocusedStream property

Stream<void> get textFieldUnfocusedStream

Stream of text field unfocused events.

Emits an event whenever a text field loses focus in any application on the device. This requires the accessibility service to be enabled.

The stream is a broadcast stream, allowing multiple listeners.

Example:

TypeMate.instance.textFieldUnfocusedStream.listen((_) {
  print('User stopped typing in a text field!');
  // Hide UI, save state, etc.
});

Note: This only works when the accessibility service is enabled and the overlay service is running.

Implementation

Stream<void> get textFieldUnfocusedStream =>
    _textFieldUnfocusedController.stream;