startOverlayService method
Starts the overlay service that tracks text input and shows bubbles.
Implementation
Future<void> startOverlayService() {
throw UnimplementedError('startOverlayService() has not been implemented.');
}
Starts the overlay service that tracks text input and shows bubbles.
Future<void> startOverlayService() {
throw UnimplementedError('startOverlayService() has not been implemented.');
}