testOverlay method
Tests the overlay by showing a bubble for a few seconds.
Implementation
Future<void> testOverlay() {
throw UnimplementedError('testOverlay() has not been implemented.');
}
Tests the overlay by showing a bubble for a few seconds.
Future<void> testOverlay() {
throw UnimplementedError('testOverlay() has not been implemented.');
}