MethodChannelTypeMate class
An implementation of TypeMatePlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- TypeMatePlatform
- MethodChannelTypeMate
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
checkAccessibilityService(
) → Future< bool> -
Checks if the accessibility service is enabled.
override
-
checkOverlayPermission(
) → Future< bool> -
Checks if overlay permission is granted.
override
-
isOverlayVisible(
) → Future< bool> -
Checks if the overlay is currently visible.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openAccessibilitySettings(
) → Future< void> -
Opens the accessibility settings for the user to enable the service.
override
-
removeTextFieldFocusListener(
) → void -
Removes the text field focus listener.
override
-
requestOverlayPermission(
) → Future< void> -
Requests system overlay permission.
override
-
setTextFieldFocusListener(
dynamic onTextFieldFocused(), dynamic onTextFieldUnfocused()) → void -
Sets a callback to receive text field focus events.
The callback receives notifications when text fields are focused/unfocused.
override
-
startOverlayService(
) → Future< void> -
Starts the overlay service that tracks text input and shows bubbles.
override
-
stopOverlayService(
) → Future< void> -
Stops the overlay service.
override
-
testOverlay(
) → Future< void> -
Tests the overlay by showing a bubble for a few seconds.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited