startOverlayService method
Start the overlay service
The overlay service will track text input across all apps and display a popup bubble when typing is detected.
Make sure to check permissions first using hasAllPermissions.
Implementation
Future<void> startOverlayService() async {
return await TypeMatePlatform.instance.startOverlayService();
}