testOverlay method
Test the overlay functionality
This will show a test bubble for a few seconds to verify that the overlay is working correctly.
Implementation
Future<void> testOverlay() async {
return await TypeMatePlatform.instance.testOverlay();
}